Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(781)

Unified Diff: chrome/browser/push_messaging/push_messaging_browsertest.cc

Issue 2620393002: Refactor budget computation to be more tuneable. (Closed)
Patch Set: Changed LayoutTest to expect integral budgets. (Also rebased) Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/push_messaging/push_messaging_browsertest.cc
diff --git a/chrome/browser/push_messaging/push_messaging_browsertest.cc b/chrome/browser/push_messaging/push_messaging_browsertest.cc
index 13b3c1008aca6941cc9eb8b4222472f824f29e9f..90a6a5673ff7474d28c688f5264a52db386a6c42 100644
--- a/chrome/browser/push_messaging/push_messaging_browsertest.cc
+++ b/chrome/browser/push_messaging/push_messaging_browsertest.cc
@@ -1240,9 +1240,10 @@ IN_PROC_BROWSER_TEST_F(PushMessagingBrowserTest,
content::WebContents* web_contents =
GetBrowser()->tab_strip_model()->GetActiveWebContents();
- // Set the site engagement score for the site. Setting it to 4 means it should
- // have enough budget for two non-shown notification, which cost 2 each.
- SetSiteEngagementScore(web_contents->GetURL(), 4.0);
+ // Set the site engagement score for the site. Setting it to 10 means it
+ // should have a budget of 4, enough for two non-shown notification, which
+ // cost 2 each.
+ SetSiteEngagementScore(web_contents->GetURL(), 10.0);
// If the site is visible in an active tab, we should not force a notification
// to be shown. Try it twice, since we allow one mistake per 10 push events.

Powered by Google App Engine
This is Rietveld 408576698